diff loadtools/flashid.c @ 973:7c18eac91457

loadtools: round out support for Intel flash families The three Intel flash families encountered so far in Calypso GSM devices are C3, W30 and W18, sizes from 2 to 8 MiB. Let's support all Intel flash chips from these 3 families across this range of sizes.
author Mychaela Falconia <falcon@freecalypso.org>
date Tue, 28 Nov 2023 18:56:40 +0000
parents 54a0bc149d9c
children ff4ce8d5ece4
line wrap: on
line diff
--- a/loadtools/flashid.c	Sat Sep 02 06:38:07 2023 +0000
+++ b/loadtools/flashid.c	Tue Nov 28 18:56:40 2023 +0000
@@ -9,11 +9,16 @@
 #include "flash.h"
 
 extern struct flash_device flashdev_28F160C3T;
+extern struct flash_device flashdev_28F160C3B;
 extern struct flash_device flashdev_28F320C3T;
+extern struct flash_device flashdev_28F320C3B;
 extern struct flash_device flashdev_28F640C3T;
 extern struct flash_device flashdev_28F640C3B;
+extern struct flash_device flashdev_28F320W30T;
+extern struct flash_device flashdev_28F320W30B;
 extern struct flash_device flashdev_28F640W30T;
 extern struct flash_device flashdev_28F640W30B;
+
 extern struct flash_device flashdev_Am29DL640G;
 extern struct flash_device flashdev_PL032J;
 extern struct flash_device flashdev_PL129J;
@@ -180,12 +185,21 @@
 	/* 28F160C3T and 28F320C3T equivalents found in some Mot C1xx phones */
 	{0x0020, 0x88BA, try_device, &flashdev_28F320C3T},
 	{0x0020, 0x88CE, try_device, &flashdev_28F160C3T},
-	/* Intel flash chips */
+	/* Intel W30 flash family */
+	{0x0089, 0x8852, try_device, &flashdev_28F320W30T},
+	{0x0089, 0x8853, try_device, &flashdev_28F320W30B},
 	{0x0089, 0x8854, try_device, &flashdev_28F640W30T},
 	{0x0089, 0x8855, try_device, &flashdev_28F640W30B},
+	/* Intel W18 flash family: same as W30, but different ID codes */
+	{0x0089, 0x8862, try_device, &flashdev_28F320W30T},
+	{0x0089, 0x8863, try_device, &flashdev_28F320W30B},
 	{0x0089, 0x8864, try_device, &flashdev_28F640W30T},
+	{0x0089, 0x8865, try_device, &flashdev_28F640W30B},
+	/* Intel C3 flash family */
 	{0x0089, 0x88C2, try_device, &flashdev_28F160C3T},
+	{0x0089, 0x88C3, try_device, &flashdev_28F160C3B},
 	{0x0089, 0x88C4, try_device, &flashdev_28F320C3T},
+	{0x0089, 0x88C5, try_device, &flashdev_28F320C3B},
 	{0x0089, 0x88CC, try_device, &flashdev_28F640C3T},
 	{0x0089, 0x88CD, try_device, &flashdev_28F640C3B},
 	/* Samsung flash */